@@ -5,6 +5,7 @@ import os
 import json
 from typing import List, Tuple, Optional, Union, Type, OrderedDict, Iterable
 import numpy as np
+import sys
 
 class Vn:
     def __init__(self):
@@ -24,6 +25,14 @@ class Vn:
         self.APIversionList: list = []
         self.LatestAPIversion: str = None
         self.network_references_all: pd.DataFrame = None
+
+        #----------------------------------------------------------------
+        # Load Network API Json
+        self.network_api_json: dict = None
+        with open(os.path.join(sys.path[0], 'network_api_v25.json'), encoding="utf-8") as file:
+            self.network_api_json = json.load(file)
+        self.network_api_parsed: dict = self.__parse_network_api_json(self.network_api_json)
+
     
     
     # Refactored - MP 20220610
@@ -80,7 +89,27 @@ class Vn:
                     'APIheaders':self.APIheaders, 
                     'APIversionList':self.APIversionList, 
                     'LatestAPIversion':self.LatestAPIversion}
+
+
     
+    def __parse_network_api_json(self, network_api: dict):
+        output = {}
+        for key, value in network_api.items():
+            if isinstance(value, dict):
+                output[key] = self.__parse_network_api_json(value)
+            elif isinstance(value, list):
+                first_key_set = set()
+                for item in value:
+                    if isinstance(item, dict):
+                        first_key_set.add(list(item.keys())[0])
+                if len(first_key_set) == 1:
+                    output[key] = self.__parse_network_api_json(self.list_of_dicts_to_dict(value, list(first_key_set)[0]))
+                else:
+                    output[key] = value
+            else:
+                output[key] = value
+        return output
+
     # Refactored - MP 20220610
     def get_networkObjects(self) -> pd.DataFrame:
         """
@@ -362,4 +391,9 @@ class Vn:
         df1['cartesian_join_key'] = 1
         df2['cartesian_join_key'] = 1
         result = pd.merge(df1, df2, on ='cartesian_join_key').drop(labels="cartesian_join_key", axis=1)
-        return result
\ No newline at end of file
+        return result
+        
+vn = Vn()
+with open(os.path.join(os.pardir, "credentials.json")) as file:
+    credentials = json.load(file)
+vn.authenticate(**credentials['VeevaNetwork'][0])
\ No newline at end of file
